@@ -17,6 +17,7 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+from io import StringIO
 from optparse import OptionParser, SUPPRESS_HELP
 from os.path import expanduser, join, dirname
 from os import access, R_OK
@@ -39,7 +40,7 @@ else: # > 3.0
     def pickle_load(f):
         return pickle.load(f,encoding="bytes")
 
-version="3.13.0"
+version="3.15.0"
 os.environ['CURRENT_VERSION_ID']=version
 
 global_cache = 'global_cache'
@@ -61,7 +62,6 @@ try:
     from calibre_plugins.fanficfare_plugin.fanficfare.epubutils import (
         get_dcsource_chaptercount, get_update_data, reset_orig_chapters_epub)
     from calibre_plugins.fanficfare_plugin.fanficfare.geturls import get_urls_from_page, get_urls_from_imap
-    from calibre_plugins.fanficfare_plugin.fanficfare.six import StringIO
     from calibre_plugins.fanficfare_plugin.fanficfare.six.moves import configparser
     from calibre_plugins.fanficfare_plugin.fanficfare.six.moves import http_cookiejar as cl
 except ImportError:
@@ -70,7 +70,6 @@ except ImportError:
     from fanficfare.epubutils import (
         get_dcsource_chaptercount, get_update_data, reset_orig_chapters_epub)
     from fanficfare.geturls import get_urls_from_page, get_urls_from_imap
-    from fanficfare.six import StringIO
     from fanficfare.six.moves import configparser
     from fanficfare.six.moves import http_cookiejar as cl
 
@@ -100,12 +99,15 @@ def main(argv=None,
     parser.add_option('-f', '--format', dest='format', default='epub',
                       help='Write story as FORMAT, epub(default), mobi, txt or html.', metavar='FORMAT')
     if passed_defaultsini:
-        config_help = 'Read config from specified file(s) in addition to calibre plugin personal.ini, ~/.fanficfare/personal.ini, and ./personal.ini'
+        config_help = 'calibre plugin defaults.ini, calibre plugin personal.ini'
     else:
-        config_help = 'Read config from specified file(s) in addition to ~/.fanficfare/defaults.ini, ~/.fanficfare/personal.ini, ./defaults.ini, and ./personal.ini'
+        config_help = '~/.fanficfare/defaults.ini, $XDG_CONFIG_HOME/fanficfare/defaults.ini, ./defaults.ini'
     parser.add_option('-c', '--config',
                       action='append', dest='configfile', default=None,
-                      help=config_help, metavar='CONFIG')
+                      help=('Read config from specified file(s) in addition to (ordered lowest to highest priority): '
+                            +config_help
+                            +', ~/.fanficfare/personal.ini, $XDG_CONFIG_HOME/fanficfare/personal.ini, and ./personal.ini.  -c/--config files take highest priority'),
+                      metavar='CONFIG')
     range_help = '  --begin and --end will be overridden by a chapter range on the STORYURL like STORYURL[1-2], STORYURL[-3], STORYURL[3-] or STORYURL[3]'
     parser.add_option('-b', '--begin', dest='begin', default=None,
                       help='Begin story with Chapter START.'+range_help, metavar='START')
@@ -129,6 +131,9 @@ def main(argv=None,
     parser.add_option('-u', '--update-epub',
                       action='store_true', dest='update',
                       help='Update an existing epub(if present) with new chapters.  Give either epub filename or story URL.', )
+    parser.add_option('-U', '--update-epub-always',
+                      action='store_true', dest='updatealways',
+                      help="Update an existing epub(if present) even if there aren't new chapters.  Give either epub filename or story URL.", )
     parser.add_option('--update-cover',
                       action='store_true', dest='updatecover',
                       help='Update cover in an existing epub, otherwise existing cover (if any) is used on update.  Only valid with --update-epub.', )
@@ -215,8 +220,12 @@ def main(argv=None,
                 print('  * %s' % u)
         return
 
+    # options.updatealways should also invoke most options.update logic.
+    if options.updatealways:
+        options.update = True
+
     if options.update and options.format != 'epub':
-        parser.error('-u/--update-epub only works with epub')
+        parser.error('-u/--update-epub/-U/--update-epub-always only work with epub')
 
     if options.unnew and options.format != 'epub':
         parser.error('--unnew only works with epub')
@@ -436,7 +445,7 @@ def do_download(arg,
             # returns int adjusted for start-end range.
             urlchaptercount = adapter.getStoryMetadataOnly().getChapterCount()
 
-            if chaptercount == urlchaptercount and not options.metaonly:
+            if chaptercount == urlchaptercount and not options.metaonly and not options.updatealways:
                 print('%s already contains %d chapters.' % (output_filename, chaptercount))
             elif chaptercount > urlchaptercount:
                 print('%s contains %d chapters, more than source: %d.' % (output_filename, chaptercount, urlchaptercount))
@@ -539,6 +548,8 @@ def get_configuration(url,
     homepath = join(expanduser('~'), '.fanficdownloader')
     ## also look for .fanficfare now, give higher priority than old dir.
     homepath2 = join(expanduser('~'), '.fanficfare')
+    xdgpath = os.environ.get('XDG_CONFIG_HOME', default=join(expanduser('~'),'.config'))
+    xdgpath = join(xdgpath, 'fanficfare')
 
     if passed_defaultsini:
         # new StringIO each time rather than pass StringIO and rewind
@@ -549,6 +560,7 @@ def get_configuration(url,
         conflist.append(join(dirname(__file__), 'defaults.ini'))
         conflist.append(join(homepath, 'defaults.ini'))
         conflist.append(join(homepath2, 'defaults.ini'))
+        conflist.append(join(xdgpath, 'defaults.ini'))
         conflist.append('defaults.ini')
 
     if passed_personalini:
@@ -558,6 +570,7 @@ def get_configuration(url,
 
     conflist.append(join(homepath, 'personal.ini'))
     conflist.append(join(homepath2, 'personal.ini'))
+    conflist.append(join(xdgpath, 'personal.ini'))
     conflist.append('personal.ini')
 
     if options.configfile:
