@@ -39,21 +39,7 @@ import pickle
 
 from . import exceptions
 
-try:
-    from google.appengine.api import apiproxy_stub_map
-    def urlfetch_timeout_hook(service, call, request, response):
-        if call != 'Fetch':
-            return
-        # Make the default deadline 10 seconds instead of 5.
-        if not request.has_deadline():
-            request.set_deadline(10.0)
-
-    apiproxy_stub_map.apiproxy.GetPreCallHooks().Append(
-        'urlfetch_timeout_hook', urlfetch_timeout_hook, 'urlfetch')
-    logger.info("Hook to make default deadline 10.0 installed.")
-except:
-    pass
-    #logger.info("Hook to make default deadline 10.0 NOT installed--not using appengine")
+logger = logging.getLogger(__name__)
 
 try:
     import chardet
@@ -78,8 +64,6 @@ from .htmlcleanup import reduce_zalgo
 # [overrides]
 # titlepage_entries: category
 
-logger = logging.getLogger(__name__)
-
 # Work around for fact that py3 apparently doesn't allow/ignore
 # recursive imports like py2 does.
 try:
@@ -235,6 +219,7 @@ def get_valid_set_options():
 
                'force_login':(['phoenixsong.net'],None,boollist),
                'non_breaking_spaces':(['fictionmania.tv'],None,boollist),
+               'download_text_version':(['fictionmania.tv'],None,boollist),
                'universe_as_series':(['storiesonline.net','finestories.com'],None,boollist),
                'strip_text_links':(['bloodshedverse.com','asexstories.com'],None,boollist),
                'centeredcat_to_characters':(['tthfanfic.org'],None,boollist),
@@ -426,6 +411,7 @@ def get_valid_keywords():
                  'never_make_cover',
                  'no_image_processing',
                  'non_breaking_spaces',
+                 'download_text_version',
                  'nook_img_fix',
                  'output_css',
                  'output_filename',
@@ -1032,9 +1018,11 @@ class Configuration(configparser.SafeConfigParser):
         max_zalgo = int(self.getConfig('max_zalgo',-1))
         if max_zalgo > -1:
             logger.debug("Applying max_zalgo:%s"%max_zalgo)
-            return reduce_zalgo(data,max_zalgo)
-        else:
-            return data
+            try:
+                return reduce_zalgo(data,max_zalgo)
+            except Exception as e:
+                logger.warn("reduce_zalgo failed(%s), continuing."%e)
+        return data
 
     # Assumes application/x-www-form-urlencoded.  parameters, headers are dict()s
     def _postUrl(self, url,
@@ -1114,7 +1102,8 @@ class Configuration(configparser.SafeConfigParser):
         cache hits.
         '''
 
-        url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&#')
+        if not url.startswith('file:'): # file fetches fail on + for space
+            url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&#')
 
         if self.getConfig('force_https'): ## For developer testing only.
             url = url.replace("http:","https:")
@@ -1212,6 +1201,12 @@ class Configuration(configparser.SafeConfigParser):
                 if he.code in (403,404,410):
                     logger.debug("Caught an exception reading URL: %s  Exception %s."%(unicode(safe_url(url)),unicode(he)))
                     break # break out on 404
+                ## trekfanfiction.net has started returning the page,
+                ## but with a 500 code.  We can use the HTTPError as
+                ## the 'opened' in such case.
+                if he.code == 500 and 'trekfanfiction.net' in url:
+                    data = he.read()
+                    return (self._do_reduce_zalgo(self._decode(data)),he)
             except Exception as e:
                 excpt=e
                 logger.debug("Caught an exception reading URL: %s sleeptime(%s) Exception %s."%(unicode(safe_url(url)),sleeptime,unicode(e)))
@@ -1343,7 +1338,7 @@ class Configurable(object):
 
 
 # .? for AO3's ']' in param names.
-safe_url_re = re.compile(r'(?P<attr>(password|name|login).?=)[^&]*(?P<amp>&|$)',flags=re.MULTILINE)
+safe_url_re = re.compile(r'(?P<attr>(pass(word)?|name|login).?=)[^&]*(?P<amp>&|$)',flags=re.MULTILINE)
 def safe_url(url):
     # return url with password attr (if present) obscured.
     return re.sub(safe_url_re,r'\g<attr>XXXXXXXX\g<amp>',url)
